<?php

namespace Bixo\Contact\Http\Resources;

use Illuminate\Http\Resources\Json\JsonResource;

class ContactResource extends JsonResource
{

    public function itemLink()
    {
        return guard_url('contact/contact') . '/' . $this->getRouteKey();
    }

    public function title()
    {
        if ($this->title != '') {
            return $this->title;
        }

        if ($this->name != '') {
            return $this->name;
        }

        return 'None';
    }

    public function toArray($request)
    {
        return [
            'id' => $this->getRouteKey(),
            'title' => $this->title(),
            'slug' => $this->slug,
            'company_id' => $this->company_id,
            'branch_id' => $this->branch_id,
            'department_id' => $this->department_id,
            'division_id' => $this->division_id,
            'agent_id' => $this->agent_id,
            'account_id' => $this->account_id,
            'type' => $this->type,
            'ref' => $this->ref,
            'title' => $this->title,
            'name' => $this->name,
            'gender' => $this->gender,
            'dob' => $this->dob,
            'passportno' => $this->passportno,
            'licenseno' => $this->licenseno,
            'nationalid' => $this->nationalid,
            'residanceid' => $this->residanceid,
            'nationality' => $this->nationality,
            'religion' => $this->religion,
            'languages' => $this->languages,
            'phone' => $this->phone,
            'mobile' => $this->mobile,
            'mobiles' => $this->mobiles,
            'email' => $this->email,
            'emails' => $this->emails,
            'address' => $this->address,
            'location_id' => $this->location_id,
            'region_id' => $this->region_id,
            'country_id' => $this->country_id,
            'time_zone' => $this->time_zone,
            'designation' => $this->designation,
            'social_urls' => $this->social_urls,
            'documents' => $this->documents,
            'notes' => $this->notes,
            'upload_folder' => $this->upload_folder,
            'user_id' => $this->user_id,
            'user_type' => $this->user_type,
            'created_at' => !is_null($this->created_at) ? $this->created_at->format('Y-m-d H:i:s') : null,
            'updated_at' => !is_null($this->updated_at) ? $this->updated_at->format('Y-m-d H:i:s') : null,
            'meta' => [
                'exists' => $this->exists(),
                'link' => $this->itemLink(),
                'upload_url' => $this->getUploadURL(''),
                'workflow' => $this->workflows(),
                'actions' => $this->actions(),
            ],
        ];
    }

    /**
     * Get additional data that should be returned with the resource array.
     *
     * @param     \Illuminate\Http\Request  $request
     * @return array
     */
    public function with($request)
    {
        return [
            'meta' => [
                'exists' => $this->exists(),
                'link' => $this->itemLink(),
                'upload_url' => $this->getUploadURL(''),
                'workflow' => $this->workflows(),
                'actions' => $this->actions(),
            ],
        ];
    }

    /**
     * Get the workflows for the resource.
     *
     * @return array
     */
    private function workflows()
    {
        $arr = [];
                $workflow = $this->resource->workflow();
        foreach ($workflow->transitions($this) as $key => $transition) {
            $name = $transition->getName();
            $arr[$key]['url'] = guard_url('contact/contact/workflow/' . $this->getRouteKey() . '/' . $name);
            $arr[$key]['name'] = $name;
            $arr[$key]['key'] = $name;
            $arr[$key]['form'] = $workflow->form($transition);
            $arr[$key]['label'] = trans('contact::contact.workflow.' . $name);
        }
                return $arr;

    }
    
    /**
     * Get the actions for the resource.
     *
     * @return array
     */
    private function actions()
    {

        $arr = [];
                $actions = $this->resource->actions()->details();
        foreach ($actions as $key => $action) {
            $name = $action->name();
            $arr[$key]['url'] = guard_url('contact/contact//action' . $this->getRouteKey() . '/' . $action->name());
            $arr[$key]['name'] = $name;
            $arr[$key]['key'] = $name;
            $arr[$key]['form'] = $action->form();
            $arr[$key]['label'] = trans('contact::contact.actions.' . $name);
        }
        
        return $arr;
    }
}
