<?php

namespace Bixo\Contact\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Contact\Events\AccountWorkflow as AccountWorkflowEvent;
use Bixo\Contact\Notifications\AccountWorkflow as AccountWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AccountWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AccountWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $account is submitted.
     *
     * @param AccountWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AccountWorkflowEvent $event)
    {
        $client = $event->account->client;
        Notification::send($client, new AccountWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $account is published.
     *
     * @param AccountWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AccountWorkflowEvent $event)
    {
        $client = $event->account->client;
        Notification::send($client, new AccountWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $account is approved.
     *
     * @param AccountWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AccountWorkflowEvent $event)
    {
        $client = $event->account->client;
        Notification::send($client, new AccountWorkflowNotification($event));
    }

    /**
     * Handles the $account workflow event as a listener.
     *
     * @param AccountWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AccountWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
