<?php

namespace Bixo\Contact\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Contact\Models\Account;

class AccountPolicy
{

    use AccountAction;

    /**
     * Determine if the given user can view the account.
     *
     * @param Authenticatable $user
     * @param Account $account
     *
     * @return bool
     */
    public function view(Authenticatable $user, Account $account)
    {
        if ($authUser->canDo('contact.account.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $account->is_owner;
    }

    /**
     * Determine if the given user can create a account.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('contact.account.create');
    }

    /**
     * Determine if the given user can update the given account.
     *
     * @param Authenticatable $user
     * @param Account $account
     *
     * @return bool
     */
    public function update(Authenticatable $user, Account $account)
    {
        if ($user->canDo('contact.account.edit') && $user->isAdmin()) {
            return true;
        }

        return $account->is_owner;
    }

    /**
     * Determine if the given user can delete the given account.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Account $account)
    {
        return $account->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
